% Positionsberechnung des Signals - MOTUARA ISLAND
%
% Es sind bekannt die Position der beiden Antennen (A & B)
% welche mit der Position des Signals (C) ein Dreieck
% bilden. Ferner sind bekannt, die korrespondierenden
% Winkel an der Basislinie (AB). Die Position des Signals
% kann nun ber eine Folge von Geradengleichungen errechnet
% werden.
%

clear all

% Eingabe der Grunddaten (XY-Koordinaten beider Antennen, abgelesene Winkel)

% Koordinaten Motuara Island
Ax = 174.2746;
Ay = -41.0955;
Bx = 174.3622;
By = -41.1250;

% Koordinaten Oamaru
%Ax = 170.9725;
%Ay = -45.1122;
%Bx = 171.0055;
%By = -45.0403;

% Plotten der Kstenlinie
motuara

% Plotten der Antennenpositionen
plot(Ax,Ay, 'r*')
plot(Bx,By, 'r*')

% Einlesen der Antennenwinkel

load data.dat
alpha = data(:,1);
beta = data(:,2);

% SCHRITT 1: Geradengleichung fr die Basislinie AB
%
% Ansatz: y=m*x+p wobei m die Steigung der Geraden AB bezeichnet.
%         Aus der errechneten Steigung m lt sich nun der Steigungs-
%         winkel der Geraden errechnen, welcher die Differenz von
%         Winkel ALPHA und dem Steigungswinkel der Geraden AC darstellt.

m = (By-Ay)/(Bx-Ax);           % Steigung der Geraden AB
angAB = atandeg(m);            % Funktion ATANDEG errechnet den inversen Tangens aus m:
angAC = alpha-angAB;           % dies ist zugleich der Steigungswinkel der Geraden AB;
                               % angAC ist der Steigungswinkel der Geraden AC
                               
                               
% ZWISCHENSCHRITT: Berechnen der Peilwinkel relativ zur Basislinie

if Ay > By                       % Bestimmung der Schnittpunkte der Basislinie AB
   crwest = 270+angAB;           % auf der Komparose: West (crwest) und Ost (creast) 
elseif Ay < By                   % sowie des 90 quivalents zur Basislinie (crnorth)
   crwest = 270-angAB
else
   crwest = 270
end
crwest = round(crwest);           
creast = crwest-180;
crnorth = round(angAB);
   
disp('Basislinie schneidet Komparose bei:')
disp([crwest creast])
disp('Der 90-Winkel zur Basislinie liegt bei:')
disp([crnorth])

if alpha > crwest
   alpha = 180-(crwest-alpha);

elseif alpha < creast
   alpha = creast-alpha;
   else alpha = -(alpha-creast);
end

if beta > crwest
   beta = beta-crwest;
elseif beta < creast
   beta = 180-(creast-beta);
   else beta = -(crwest-beta)
end

disp('alpha')
disp([alpha])
disp('beta')
disp([beta])

% Sind die Winkel ALPHA und BETA logisch?

if alpha+beta >=180
   error('DIE PEILUNG HAT KEINEN SCHNITTPUNKT!')
end

% Wurde nach Norden oder Sden gepeilt?

if alpha < 0 
   if beta > 0
      error('FEHLER! Station A peilte nach Sden; Station B nach Norden!')
      end
   elseif alpha > 0 
      if beta < 0
         error('FEHLER! Station A peilte nach Norden; Station B nach Sden!')
         end
      elseif alpha < 0 
         if beta < 0
            disp('Es wurde nach Sden gepeilt')
            end
else
   disp('Es wurde nach Norden gepeilt')
end
   
   
% SCHRITT 2: Geradengleichung fr die Gerade AC
%
% Ansatz: Der Steigungswinkel angAC ergibt die Steigung mAC der Geraden AC: mAC=tan(angAC).
%         Daraus lt sich die Steigungsfunktion der Geraden errechnen: AC(x) = mAC*x+pAC.
%         Diese Gerade geht durch den Punkt A dessen Koordinaten bekannt sind, so da 
%         Einsetzten der Koordinaten von A in die Funktion zur Errechnung von pAC benutzt
%         werden knnen: pAC=y-(x*mAC).

mAC = tandeg(angAC);           % Steigung der Geraden AC
pAC = Ay-(Ax*mAC);


% SCHRITT 3: Geradengleichung fr die Gerade BC
%
% Ansatz: Der Steigungswinkel angBC der Geraden BC kann aus den bekannten Steigungswinkel
%         der Geraden AB und dem bekannten Winkel BETA berechnet werden: angBC = 180-(atan(m)+BETA)
%         Der errechnete Steigungswinkel kann - wie in Schritt 2 - benutzt werden um die Funktion
%         BC(x) zu errechnen: BC(x) = mBC*x+pBC

angBC = 180-(atandeg(m)+beta);   % Steigungswinkel der Geraden BC
mBC = tandeg(angBC);             % Steigung der Geraden BC
pBC = By-(Bx*mBC);

% SCHRITT 4: Berechnung der Koordinaten des Punktes C
%
% Ansatz: Im Punkt C schneiden sich die Geraden AC und BC, d.h. in diesem Punkt haben die
%         Funktionen AC(x) und BC(x) den gleichen Wert: AC(x) = BC(x). Das Gleichsetzen der
%         Funktionen liefert die X-Koordinate von C: mBC*x+pBC = mAC*x+pAC.
%         Die Y-Koordinate errechnet sich durch Einsetzen der X-Koordinate in eine der
%         beiden Funktionen.
%
% Anmerkung: Die beiden FOR-Schleifen sind notwendig um die Problematik gleicher Matrizengren zu umgehen


lg = length(mAC);
Cx = -999;
Cy = -999;
for i = 1:lg
   Cxi = (pAC(i,:)-pBC(i,:))/(mBC(i,:)-mAC(i,:));      % Berechnen der X-Koordinate von C
   Cx = [Cx; Cxi];
   %Cyi = mAC(i,:)*Cx(i,:)+pAC(i,:);           % Berechnen der Y-Koordinate von C durcheinsetzen von Cx in AC(x)
   %Cy = [Cy; Cyi];
end
Cx(1,:) = [];

for i = 1:lg
   Cyi = mAC(i,:)*Cx(i,:)+pAC(i,:);           % Berechnen der Y-Koordinate von C durcheinsetzen von Cx in AC(x)
   Cy = [Cy; Cyi];
end
Cy(1,:) = [];          



disp('X-Koordinate von C:')
disp([Cx])
disp('Y-Koordinate von C:')
disp([Cy])

plot(Cx,Cy, '-x')